@@ -25,10 +25,16 @@ http://stackoverflow.com/questions/2090717/getting-translation-strings-for-jinja
 """
 
 import re
+
+from django import VERSION as DJANGO_VERSION
 from django.core.management.commands import makemessages
-from django.utils.translation import trans_real
 from django.template.base import BLOCK_TAG_START, BLOCK_TAG_END
 
+if DJANGO_VERSION[:2] < (1, 11):
+    from django.utils.translation import trans_real
+else:
+    from django.utils.translation import template as trans_real
+
 strip_whitespace_right = re.compile(r"(%s-?\s*(trans|pluralize).*?-%s)\s+" % (BLOCK_TAG_START, BLOCK_TAG_END), re.U)
 strip_whitespace_left = re.compile(r"\s+(%s-\s*(endtrans|pluralize).*?-?%s)" % (BLOCK_TAG_START, BLOCK_TAG_END), re.U)
 
@@ -53,11 +59,11 @@ class Command(makemessages.Command):
             trans_real.block_re.pattern + '|' + r"""^-?\s*trans(?:\s+(?!'|")(?=.*?=.*?)|\s*-?$)""")
         trans_real.plural_re = re.compile(
             trans_real.plural_re.pattern + '|' + r"""^-?\s*pluralize(?:\s+.+|-?$)""")
-        trans_real.constant_re = re.compile(r"""_\(((?:".*?")|(?:'.*?')).*\)""")
+        trans_real.constant_re = re.compile(r"""_\(((?:".*?(?<!\\)")|(?:'.*?(?<!\\)')).*\)""")
 
-        def my_templatize(src, origin=None):
+        def my_templatize(src, origin=None, **kwargs):
             new_src = strip_whitespaces(src)
-            return old_templatize(new_src, origin)
+            return old_templatize(new_src, origin, **kwargs)
 
         trans_real.templatize = my_templatize
 
